package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(R``````````0```````
M`,&H``````!``#@`"@!``!L`&@````8````$`````````$``````````0```
M``````!``````````C`````````",``````````(`````P````0````````"
ME`````````*4`````````I0`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*Q$````````K$0`
M```````0``````$````&````````N[@```````"[N````````+NX````````
M!-`````````$^````````!```````@````8```````"[R````````+O(````
M````N\@````````"``````````(```````````@````$````!`````````)P
M`````````G`````````"<``````````D`````````"0`````````!`````0`
M```$````````JS@```````"K.````````*LX`````````0P````````!#```
M```````$9'3E4`````0```````"D.````````*0X````````I#@`````````
M[`````````#L``````````1D=.51````!@``````````````````````````
M````````````````````````````````````$&1TY5(````$````````N[@`
M``````"[N````````+NX````````!$@````````$2``````````!````!```
M`!0````#1TY5`&MJ\DOJR7IFW+E70<`K%71K^*]++VQI8B]L9#8T+G-O+C$`
M```````````1````0P````0````(A`1`!0`0$""$`(:`!``"*`@$(`D"`(F"
M"`(`ND$0@(@`````````0P```$8```!)````2@```%(```!3````5```````
M``!6````5P```%@```!9````6@```%P``````````!_?Q6XM1][.?)I_:[:;
MQ2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/
MF=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,%0N7.@V;G*E_"@*GX%">&FM)^^"C
M```````````````````````````````````````````#```*````````&6@`
M`````````````W02`````````````````````````````I\2````````````
M`````````````````(P1`````````````````````````````<,2````````
M`````````````````````@82`````````````````````````````H82````
M`````````````````````````+T2`````````````````````````````D(2
M``````````````````````````````$@````````````````````````````
M`G\2`````````````````````````````&<2````````````````````````
M`````;82`````````````````````````````,82````````````````````
M`````````M$2`````````````````````````````842````````````````
M`````````````?82`````````````````````````````2D2````````````
M`````````````````6H2`````````````````````````````)02````````
M`````````````````````!`@`````````````````````````````K<2````
M`````````````````````````2`2`````````````````````````````(H1
M`````````````````````````````3<2````````````````````````````
M`"P@`````````````````````````````)T2````````````````````````
M`````JD2`````````````````````````````4T2````````````````````
M`````````.$6`````````````````````````````/02````````````````
M`````````````7X2`````````````````````````````E42````````````
M`````````````````0\2`````````````````````````````L(2````````
M`````````````````````+,2`````````````````````````````%@B````
M`````````````````````````=`2`````````````````````````````;$2
M`````````````````````````````3X2````````````````````````````
M`<H2`````````````````````````````6,2````````````````````````
M`````:(2`````````````````````````````I$2````````````````````
M`````````B<2`````````````````````````````'D2````````````````
M`````````````7<2`````````````````````````````>$2````````````
M`````````````````)P2`````````````````````````````-H2````````
M`````````````````````A(2`````````````````````````````;X2````
M`````````````````````````G,2`````````````````````````````J02
M`````````````````````````````>\2````````````````````````````
M`F81`````````````````````````````8P2````````````````````````
M`````*02`````````````````````````````,P2````````````````````
M`````````002`````````````````````````````542````````````````
M`````````````*L2`````````````````````````````C,2````````````
M`````````````````$82`````````````````````````````902````````
M`````````````````````9L1`````````````````````````````WT2```,
M````````7W``````````V@```](2```,````````5%`````````(T@```%,2
M```,````````()`````````"D````O02```,````````1#``````````!@``
M`Q(2```,````````73`````````"0````_@2```,````````1$`````````#
MM@```[@0```8````````P(@``````````````P42```,````````2```````
M````0````R@2```,````````3X``````````B````XD1```.````````8W``
M````````!````Z42```,````````8+`````````!0````[`2```,````````
M0P``````````.````\T0```8````````P+```````````````^82```,````
M````4L`````````!D```!`\2```,````````4!``````````@@```Y@0```7
M````````P````````````````TP2```,````````2$`````````!D@```]\0
M```8````````P(@`````````````!`41```7````````P(``````````"```
M`YX2```,````````(R```````````````\02```,````````8%``````````
M7@```YH@```7````````P````````````````V(2```,````````4H``````
M````-@```S82```,````````0T``````````Z@```U@2```,````````8?``
M```````!/```!!<2```,````````2>`````````%E@!?7V=M;VY?<W1A<G1?
M7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!?
M7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV:7)O;@!S
M=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`&-L;W-E
M9&ER`')M9&ER`%]?<W!R:6YT9E]C:&L`=6YL:6YK`%!,7V-U<G)E;G1?8V]N
M=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L
M86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T
M<'9N`')E86QL;V,`7U]M96UM;W9E7V-H:P!G971P:60`7U]M96UC<'E?8VAK
M`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M8W!Y`'-T9&5R<@!?
M7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G971U:60`;6MD:7(`
M7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V
M7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES
M7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U;@!L:6)P
M97)L+G-O+C4N-#``;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7V)S<U]S
M=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,
M24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,@````````(``0`"``(`
M`0`!``(``0`!``(``P`"``(``0`"``$``0`$``(``0`!``(``@`"``$`!0`!
M``(``0`!``(``0`!``$``@`"``(``@`!``(``@`&``$``0`&``(`!@`%``(`
M`0`"``$``@`"``$``@`"``8``0`$``(``0`'``(``@`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`&```"
MZ@```!``````!I:1M`````<```0D````$`UI:10````&```$+P```!`&EI&S
M````!0``!#D````0"6D9=`````0```1$````$`EI&7(````#```$4````!`-
M:6D2`````@``!%P`````````````N[@`````````#````````"1`````````
MN\``````````#````````"/P````````OZ@`````````#````````%TP````
M````O^@`````````#````````,"`````````O_@`````````#````````""0
M````````P`@`````````#````````,`(````````P"``````````#```````
M`*/@````````P"@`````````#````````&/,````````P#@`````````#```
M`````&1L````````P$``````````#````````&1P````````P$@`````````
M#````````*/4````````P%``````````#````````&/2````````P%@`````
M````#````````*/<````````P&@`````````#````````*/$````````P'``
M````````#````````*/*````````P(``````````#````````&94````````
MOY`````$````"@``````````````````OY@````)````"@``````````````
M````OZ`````*````"@``````````````````O[`````5````"@``````````
M````````O[@````:````"@``````````````````O\`````>````.```````
M````````````O\@````?````"@``````````````````O]`````A````"@``
M````````````````O]@````E````"@``````````````````O^`````X````
M"@``````````````````O_````!"````"@``````````````````O>`````"
M````"P``````````````````O>@````#````"P``````````````````O?``
M```%````"P``````````````````O?@````&````"P``````````````````
MO@`````'````"P``````````````````O@@````(````"P``````````````
M````OA`````+````"P``````````````````OA@````,````"P``````````
M````````OB`````-````"P``````````````````OB@````.````"P``````
M````````````OC`````/````"P``````````````````OC@````0````"P``
M````````````````OD`````1````"P``````````````````OD@````2````
M"P``````````````````OE`````3````"P``````````````````OE@````4
M````"P``````````````````OF`````6````"P``````````````````OF@`
M```7````"P``````````````````OG`````9````"P``````````````````
MOG@````;````"P``````````````````OH`````<````"P``````````````
M````OH@````=````"P``````````````````OI`````@````"P``````````
M````````OI@````B````"P``````````````````OJ`````C````"P``````
M````````````OJ@````D````"P``````````````````OK`````E````"P``
M````````````````OK@````F````"P``````````````````OL`````G````
M"P``````````````````OL@````H````"P``````````````````OM`````I
M````"P``````````````````OM@````J````"P``````````````````ON``
M```K````"P``````````````````ON@````L````"P``````````````````
MOO`````M````"P``````````````````OO@````N````"P``````````````
M````OP`````O````"P``````````````````OP@````P````"P``````````
M````````OQ`````Q````"P``````````````````OQ@````R````"P``````
M````````````OR`````S````"P``````````````````OR@````T````"P``
M````````````````OS`````U````"P``````````````````OS@````V````
M"P``````````````````OT`````W````"P``````````````````OT@````Y
M````"P``````````````````OU`````Z````"P``````````````````OU@`
M```[````"P``````````````````OV`````\````"P``````````````````
MOV@````]````"P``````````````````OW`````^````"P``````````````
M````OW@````_````"P``````````````````OX````!`````"P``````````
M````````OX@```!!````"P``````````ZV_P,``DN00`'Z?[_V#C$/```"3`
MP```4B;`$```4P_C$!````2Y`@`1IX0``PWAXT#Q$``$ZV_PT``$!_0``.,0
M\#@`),`0``!2#=('\#`0".,0$!``!`?Q!P`'``<`P!```%(,XQ`0```$!_$-
M$.,0$`P`%,#T____Y0````#`$```4@#C$!````0'\0T0XQ`0#``4P/3____5
M````&,`0``!1].,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```%'HXQ`0
M```$!_$-$.,0$`P`%,#T____M0```$C`$```4=SC$!````0'\0T0XQ`0#``4
MP/3___^E````8,`0``!1T.,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!``
M`%'$XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```4;CC$!````0'\0T0
MXQ`0#``4P/3___]U````J,`0``!1K.,0$```!`?Q#1#C$!`,`!3`]/___V4`
M``#`P!```%&@XQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```493C$!``
M``0'\0T0XQ`0#``4P/3___]%````\,`0``!1B.,0$```!`?Q#1#C$!`,`!3`
M]/___S4```$(P!```%%\XQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```
M47#C$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!19.,0$```!`?Q#1#C
M$!`,`!3`]/___P4```%0P!```%%8XQ`0```$!_$-$.,0$`P`%,#T___^]0``
M`6C`$```44SC$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!10.,0$```
M!`?Q#1#C$!`,`!3`]/___M4```&8P!```%$TXQ`0```$!_$-$.,0$`P`%,#T
M___^Q0```;#`$```42CC$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!1
M'.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```%$0XQ`0```$!_$-$.,0
M$`P`%,#T___^E0```?C`$```403C$!````0'\0T0XQ`0#``4P/3___Z%```"
M$,`0``!0^.,0$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```%#LXQ`0```$
M!_$-$.,0$`P`%,#T___^90```D#`$```4.#C$!````0'\0T0XQ`0#``4P/3_
M__Y5```"6,`0``!0U.,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```%#(
MXQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```4+SC$!````0'\0T0XQ`0
M#``4P/3___XE```"H,`0``!0L.,0$```!`?Q#1#C$!`,`!3`]/___A4```*X
MP!```%"DXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`$```4)CC$!````0'
M\0T0XQ`0#``4P/3___WU```"Z,`0``!0C.,0$```!`?Q#1#C$!`,`!3`]/__
M_>4```,`P!```%"`XQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```4'3C
M$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!0:.,0$```!`?Q#1#C$!`,
M`!3`]/___;4```-(P!```%!<XQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`
M$```4%#C$!````0'\0T0XQ`0#``4P/3___V5```#>,`0``!01.,0$```!`?Q
M#1#C$!`,`!3`]/___84```.0P!```%`XXQ`0```$!_$-$.,0$`P`%,#T___]
M=0```ZC`$```4"SC$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!0(.,0
M$```!`?Q#1#C$!`,`!3`]/___54```/8P!```%`4XQ`0```$!_$-$.,0$`P`
M%,#T___]10```_#`$```4`CC$!````0'\0T0XQ`0#``4P/3___TU```$",`0
M``!/_.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!```$_PXQ`0```$!_$-
M$.,0$`P`%,#T___]%0``!#C`$```3^3C$!````0'\0T0XQ`0#``4P/3___T%
M```$4,`0``!/V.,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```$_,XQ`0
M```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```3\#C$!````0'\0T0XQ`0#``4
MP/3___S5```$F,`0``!/M.,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!``
M`$^HXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```3YSC$!````0'\0T0
MXQ`0#``4P/3___RE```$X,`0``!/D.,0$```!`?Q#1#C$!`,`!3`]/___)4`
M``3X``````````#K;_`P`"2R3P"PN00`[^N[`"``#;)/`+'C\/\X_W'CX/``
M`"3C,/"H`"3C0/"@`"10(/"T04#PH$$P\*C2!_#`L"A!(/"TP.7___^IQ$@`
M`$]>Q"@``$]WN00`-,#E```A(L08``!/=Y4`$`"GA`"YP#```$]@XU`P```$
M6*#PM.-EL```!.R:``0`V)8#9(JY%`#IZRX``P`-IZH``\#E___^[>,0\*@`
M!,`P``!/H^,`$```!.-@,```!.,`(```)%B0\+2Y!`!2XV!0$``DQ"L``$^<
MP$```")UXT!0&``DP"```")MXR!0"``D[)P`Q0%^[$D``P#8[`G__P#80>`0
M"*<H``2G`0`!IW0`@H@```&Y%`!BZT8``P`-XV#@```$[!(``0#8XV10```D
MN10`,>L3``,`#>,PX`@`!*<J``+C,5```"2GZP`0IP;_X^SI``,`V,0H``!/
M8+D4`)ZY%`!*ZZD``P`-0>I0`.5(X````*=I``#`,```#A/`Y?___!SL*`!4
M`'[$*```3T9!8/"\P.7___WAN00`-KD$`)+`(```(/7`Y0``##OL*`!'`'S$
M*```3S'`Y?__^\[`Y?___/O5!_#`L"BG=`!9N00`*>MO\/@`!`?^P.7___RM
MQ"L``$\:["@`3@!\P.7___TDP#```$Z=XR`P```$XT*P```$D@!)!J?T_S7C
M,.````2G*``%XS!0(``D0>`0$.PD_W9@=J?T_Y3$*```3O7`Y?___"*G]/^I
MP%```$[IXR!0```"IX0`!\#E```>2:?T_[&Y!``VP"```"!QP.4```O?Q"L`
M`$[4["C_I`!\I_3_[:?H``2G]/]NP.7___V,IRD``<#E___]%T%`\`CC,/``
M``2G"?_PN8``\*?[_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```3E7C
M("````3`Y?___G<```<'!P<'!P<'!P<'!P<'P!```$Z,P"```$Z)[!(`"H!D
MQ!@``$X7[!@`!`!\!_$'_@<'!P<'!P<'!P<'!P<'P!```$YTP"```$YQN0D`
M$NL!``,`"NLQ`#\`#+D(`##K,P`!``KL.``-`'S$&```3?;L&``'`'S`(```
M3E@'\0?^!P<'!P<'!P<'!P<'!P?KO_!8`"3`L```3DGC\/]@_W&5`+``IW0`
M%<`0``!-Y^,0$````J>$``C$*```3??`Y?___'3`Y?___Z62`;``Z[_P^``$
M!_X'!P<'!P<'!\#T____L`<'!P<'!P<'!P?K;_`P`"2R3P"PN00`[^/P_-#_
M<>/@\```).OK`"``#;)/`.'G8`\/`$1!H/"HT@?S*.`HN00`&D%0(#BY!``Z
MITD`!.<`4``P!J=;`!#G(``@,#CG$&```&CG0A``,&'G,A``,&#G0#``,`[G
M,#`0,`ZG.P`@IT?_Y^?`H!`X!N?@H"`X!N<@H#`X!N=0#P\`1*<)`"#G`!!H
M.`;G<@``!%;G(!!`.`;G0!``.`:G&P`0YV(```YMYQ9```YMYS'```YMYU,`
M'SPXYW,``3PPYX5P``YJYZA0``QHYZ`0<#@.Y\X```Q6Y^<```A6IP?_U..P
M(`@`!..@(!``!./0(!@`!.-0(```!./0\*``).,P\*@`!+GGT$JY@`!+N8(`
M3>QU(+\E6<(Z6H)YF>QU(#H%5N,P("``"..`\+``!+D(`'/C`/"X``2Y"`!T
MXT#PP``$PHI:@GF9PDI:@GF9N0@`C<(*6H)YF;D(``KK:P`"``SK-0`"``SL
M:P`A'E;L-0`A'E;LEB"_`%6Y@@!CN>>0&KF``!6Y@@`:N0@`&.R'(+\`5;F`
M`&BY@@!IN0@`8+GHD`3C0/#(``3LUSN_)5G"2EJ">9GLV``Z!5:Y"``=['$@
MOP!5[!$[OR59[!<`.@56N0@`%NN8``(`#.QC(+\`5>R8`"$>5NS1.[\E6>R!
M(+\`5;F"`#FYY'`3N8(`%KD(`!"YZ&`$XT#PT``$N00`/<)*6H)YF>PX`#H%
M5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_`%6Y@@"3Y]`/#PA$
MN>2`&;F"`!:Y"``0N>A@!.-`\-@`!+D$`)W"2EJ">9GLEP`Z!5:Y"``9[&,@
MOP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6N0@`$+GH
M8`3C0/#@``2Y!``]PDI:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E6>LW``(`
M#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!"YZ&`$XT#PZ``$N00`G<)*
M6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L@2"_`%6Y
M@@`YN>1P$[F"`!:Y"``0N>A@!.-`\/``!+D$`#W"2EJ">9GL.``Z!5:Y"``3
M[&D@OP!5[-$[OR59ZS<``@`,[#<`(1Y6['$@OP!5N8(`D[GD@!FY@@`6N0@`
M$+GH8`3C0/#X``2Y!`"=PDI:@GF9[)<`.@56N0@`&>QC(+\`5>S1.[\E6>N8
M``(`#.R8`"$>5NR!(+\`5;F"`#FYY'`3N8(`%KD(`!"YZ&`$XT#Q```$N00`
M/<)*6H)YF>PX`#H%5KD(`!/L:2"_`%7LT3N_)5GK-P`"``SL-P`A'E;L<2"_
M`%6Y@@"3N>2`&;F"`!:Y"``0N>A@!.-`\0@`!+D$`)W"2EJ">9GLEP`Z!5:Y
M"``9[&,@OP!5[-$[OR59ZY@``@`,[)@`(1Y6[($@OP!5N8(`.;GD<!.Y@@`6
MN0@`$+GH8`3C0/$0``2Y!``]PDI:@GF9[#@`.@56N0@`$^QI(+\`5>S1.[\E
M6>LW``(`#.PW`"$>5NQQ(+\`5;F"`).YY(`9N8(`%KD(`!"YZ&`$XT#Q&``$
MN00`G<)*6H)YF>R7`#H%5KD(`!GL8R"_`%7LT3N_)5GKF``"``SLF``A'E;L
M@2"_`%6Y@@`YN>1P$[F"`!:Y"``0N>A@!.-`\2``!+D$`#WL.``Z!5;L:2"_
M`%6Y"``3PDI:@GF9ZS<``@`,[#<`(1Y6N8(`D^QQ(+\`5>S1.[\E6;GD@!FY
M!`"=N8(`%NR7`#H%5KD(`!"YZ&`$XT#Q*``$N0@`&>QC(+\`5>N8``(`#.R8
M`"$>5KF"`#GL@2"_`%7LT3N_)5G"2EJ">9FYY'`3N00`/>PX`#H%5KF"`!:Y
M"``0N>A@!+D(`!/L:2"_`%7K-P`"``SC0/$P``3L-P`A'E:Y@@"3['$@OP!5
M[-$[OR59N>2`&;D$`)WLEP`Z!5:Y@@`6PDI:@GF9N0@`$+GH8`2Y"``9[&,@
MOP!5ZY@``@`,[)@`(1Y6N8(`.>R!(+\`5>S1.[\E6>-`\3@`!+GD<!.Y!``]
M[#@`.@56N8(`%KD(`!"Y"``3ZS<``@`,[#<`(1Y6XW#Q0``$PDI:@GF9N>A@
M!.QI(+\`5<)Z6H)YF;F"`).YZ&!'N8``F.S1.[\E6;F"`);LT2`Z!5;K:``"
M``S`&@````#L:``A'E;C@/%(``3L<R"_`%6Y"`"0N8(`-KD(`)VY@``Q[`D[
MOR59N8(`-^P)(#H%5KD(`#3K00`"``RY"``P[$$`(1Y6[!,[OR59[!,@.@56
MN>=`UL**;MGKH;F"`-FY"`!XN1H`?;D(`''C$/%8``3C`/%0``3LV2*_/EG"
M&F[9ZZ'LV0(A'E:Y&@`4N>?0A.Q#(K\^6;F"`(/L0P(A'E:YYT`]N8(`-\(*
M;MGKH;D:`!.Y&@`&XS#Q:``$N00`D+D:`)CC@/%@``3L9SN_)5GL9R`Z!5:Y
M"`"6PHINV>NA[&D[OR59N1H`C>QI(#H%5NS7(K\^6;D(`!;LUP(A'E;".F[9
MZZ&YY]!TN1H`-+F"`'GL22*_/EGL20(A'E:YYT"=N8(`D>P!.[\E6;D:`#GL
M`2`Z!5;CD/%P``2Y&@"'[&$BOSY9N0@`@.QA`B$>5NP(.[\E6>,0\7@`!.P(
M(#H%5KD(`##"FF[9ZZ&YYV!TPAINV>NAN8(`>+D:`!3L2"*_/EGL2`(A'E;C
M@/&```2Y&@"=PHINV>NAN1H`E[D:`(:YYT!V[-,[OR59N8(`<^S3(#H%5KD:
M`!>Y"`"=[&,BOSY9[`D[OR59[&,"(1Y6[`D@.@56N0@`$.PQ.[\E6>PQ(#H%
M5K/!`%/C,/&(``2YYV`$PCINV>NAN8(`";D:`#3L>2*_/EFSS0!%['D"(1Y6
MXY#QD``$N1H`@,*:;MGKH;D(`(2YYW`&N1H`EKF"``'LV#N_)5FY&@`P[-@@
M.@56[&$BOSY9N0@`/>QA`B$>5NP3.[\E6>P3(#H%5KGG8-?C0/&8``2Y@@#8
MN1H`G;D(`)'L&"*_/EGL&`(A'E;C@/&@``2YYQ#6PDINV>NAN8(`T[D:`$?L
M"3N_)5FY&@!-[`D@.@56PHINV>NAN0@`0+D:`(;L8R*_/EGL8P(A'E;L-#N_
M)5GL-"`Z!5:SP0`CXS#QJ``$N>=@`<(Z;MGKH;F"``FY&@`Q['DBOSY9L\T`
M$NQY`B$>5N.0\;``!+D:`(#"FF[9ZZ&Y"`"!N>=P!KD:`);LV#N_)5GLV"`Z
M!5:SP0`=L\T`8;F"``3LU"*_/EFY&@`P[-0"(1Y6N0@`-KGGT`?L0SN_)5FY
M@@`([$,@.@56N1H`D+D(`)3L:3N_)5GL:2`Z!5;C$/&X``2SP0`VXV#QP``$
ML\T``\(:;MGKH>Q((K\^6;D:`!?L2`(A'E;":F[9ZZ&YYT"-N1H`;;F"`(/L
MTR*_/EFY&@`8[-,"(1Y6N0@`$.PQ.[\E6>PQ(#H%5K/!`%/C,/'(``2YY]!T
MPCINV>NAN1H`-+/-`$6Y@@!Y[(DBOSY9N1H`9^R)`B$>5KD(`&2YYX"=[`8[
MOR59N8(`D>P&(#H%5KD:`#GL02*_/EFY"``P[$$"(1Y6[!,[OR59[!,@.@56
ML\$`8>,0\=@`!+GG0`C"&F[9ZZ'C</'0``2Y&@`8L\T`AKF"``;">F[9ZZ&Y
M&@!]N1H`<+D(`'CLAR"_`%7LESN_)5GLF``Z!5;LUB*_/EGC`/'H``3LU@(A
M'E:YY]!DN8(`8[D:`!:Y"``9XY#QX``$[&,BOSY9PIINV>NA[&,"(1Y6N1H`
ME+GG8#WL03N_)5FY@@`WP@J/&[S<['$@OP!5N1H`#>L8``(`#.P8`"$>5NS1
M(+\`5;GDT(;L1P`Z!5:Y&@"3N>80-KF``#>Y@0`XXX#Q\``$N0@`E+D(`##L
M22"_`%7C`/'X``3LF3N_)5GLE``Z!5;"BH\;O-RY"``YN1H`ANN7``(`#.R7
M`"$>5KGDT'FY@0`9N8``%+F!`!>Y"``8[&,@OP!5P@J/&[S<[#,[OR59N0@`
M#>PV`#H%5KD(`#'K%``"``SL%``A'E;LT2"_`%6YY-")N>802;F``$:Y@0!(
M[(,@OP!5N0@`0.,`\@``!.PS.[\E6>PX`#H%5KD(`#3L<R"_`%7L0SN_)5GC
M,/((``3""H\;O-RY&@`)ZY8``@`,[)8`(1Y6N>30:;F!`!FY@``8N8$`%KD(
M`!#L1P`Z!5;".H\;O-RY"`!!N>C0`^L8``(`#.P8`"$>5NS1(+\`5;GDT(FY
MYA!IN8``9[F!`&CLA""_`%6Y"`!@[$0[OR59XP#R$``$[$@`.@56N0@`1NQD
M(+\`5>PT.[\E6>-`\A@`!,(*CQN\W+D:``G"2H\;O-SKEP`"``SLEP`A'E:Y
MY-!YN8$`&;F``!BY@0`7N0@`$+GHT`3L-@`Z!5:Y"``QZQ@``@`,[!@`(1Y6
M[-$@OP!5N>80B;GDT'FY@`"&N8$`A^-P\B@`!+D(`(#C`/(@``3L0R"_`%7"
M"H\;O-RY&@`)PGJ/&[S<[#,[OR59[#0`.@56N0@`..N&``(`#.R&`"$>5KGD
MT&BY@0`8N8``%+F!`!:Y"``0N>C0!^R3(+\`5>PS.[\E6>PY`#H%5KD(`#'K
M%``"``SL<R"_`%7L%``A'E;L,SN_)5GLT2"_`%6YYA!(N>30:+F``$GL-P`Z
M!5:Y@0!&N0@`0.,`\C``!+D(`#3L0R"_`%7L8SN_)5GC,/(X``3""H\;O-RY
M&@`(ZXD``@`,[(D`(1Y6N>:`D;GDT!CL9``Z!5:Y@`"7PCJ/&[S<N8$`D;D(
M`#VSP0`CN0@`D+/-``*Y"`"6ZQ<``@`,[!<`(1Y6[-$@OP!5N>30>+GF$#CL
M:3N_)5FY@``TN8$`-^QY(+\`5>.0\D``!.QG`#H%5KD(`##"FH\;O-RY"``V
ML\$`&;/-`&'KE``"``RY&@!H[)0`(1Y6[$,@OP!5N>30";F!`!FY@``7N8$`
M$+D(`!;C8/)(``3L,SN_)5G":H\;O-RYZ-`&[#0`.@56N0@`,>L7``(`#.P7
M`"$>5NS1(+\`5;GF$'FYY-")N8``=+F!`'BY"`!PXP#R4``$[(,@OP!5P@J/
M&[S<[#,[OR59N1H`">PX`#H%5KGH,)?K-``"``SL>2"_`%7L-``A'E;L23N_
M)5GCD/)8``2YY-!CN8$`$\*:CQN\W+F``!BY@0`6N0@`$+GHT`GL1P`Z!5:Y
M"`!!ZQ@``@`,[!@`(1Y6[-$@OP!5N>808[GDT(.Y@`!GN8$`:+D(`&#C`/)@
M``3LA""_`%7""H\;O-SL1#N_)5FY&@`#[$@`.@56N>A`-NQC(+\`5>Q#.[\E
M6>,P\F@`!.N7``(`#,(ZCQN\W.R7`"$>5KGDT'FY@0`9N8``&+F!`!>Y"``0
MN>C0`^,P\G``!.Q&`#H%5KD(`$'K&``"``SL&``A'E;L<2"_`%6YY'")N>80
MV<(ZCQN\W+F``-:Y&@`YN8$`V.N6``(`#.R$(+\`5>R6`"$>5KD(`-#L1#N_
M)5GL2``Z!5:Y"`!-[&0[OR59[-0@OP!5N>:00;D$`!;C8/)X``2YY'`)[!T`
M.@56N8``2,)JCQN\W+F!`$"Y"`!#N>AP-KD(`$'K&``"``SL&``A'E;L<2"_
M`%6YYA")N>1P:;F``(VY@0"&N0@`@^,P\H``!.P$.[\E6<(ZCQN\W.P$(#H%
M5KD:`#FSP0`#N0@`@.MM``(`#.,P\H@`!+D$`);LG0`A'E:YY'`)L\T`8,!*
M`````+F!`!FY@``4N8$`$.,`\I``!,(ZRF+!UKGH<'.Y"``6[-@[OR59L\$`
M)^S8(#H%5NMT``(`#,(*RF+!UNQT`"$>5KD:``FYYW!)L\$`0+F"`$CL:"*_
M/EFSS0`R[&@"(1Y6L\T`A+D(`!WLT3N_)5GLT2`Z!5:Y&@`TN0@`/;GG8-?L
M0SN_)5FY@@#1[$,@.@56N1H`C;D(`(3LF#N_)5GLF"`Z!5;C`/*8``2SP0!9
MXY#RH``$L\T`U<(*RF+!UL*:RF+!UKD:``>Y&@"6['$BOSY9['$"(1Y6N00`
M$+GG<$;L8R*_/EFY@@!#[&,"(1Y6N1H`%+D(`!WL,3N_)5GL,2`Z!5:YYV`'
MXT#RJ``$N8(`"+D:`)"Y"`"3[#@BOSY9[#@"(1Y6XX#RL``$N><P!L)*RF+!
MUKF"``&Y&@!'[-D[OR59N1H`0.S9(#H%5L**RF+!UKD(`$VY&@"&[&$BOSY9
M[&$"(1Y6[!0[OR59[!0@.@56L\$``>,0\K@`!+GG8-/"&LIBP=:Y@@#9N1H`
M$^QY(K\^6;/-`##L>0(A'E;CD/+```2Y&@"-PIK*8L'6N0@`@[GG<-:Y&@"6
MN8(`U.,P\L@`!+D:`!WL"#N_)5GL9"*_/EGL""`Z!5;L9`(A'E:Y"``0[$$[
MOR59[$$@.@56N>=@![F"``BY&@"0N0@`E.Q((K\^6>Q(`B$>5N.`\M``!+GG
M0`;".LIBP=:Y@@`!N1H`-^S9.[\E6;D:`##LV2`Z!5;"BLIBP=:Y"``]N1H`
MANQA(K\^6>QA`B$>5NP3.[\E6>P3(#H%5K/!`#'C$/+8``2YYV#4PAK*8L'6
MN8(`V;D:`!3L>2*_/EFSS0!#['D"(1Y6XY#RX``$N1H`C<*:RF+!UKD(`(2Y
MYW#6N1H`EKF"`-/L"#N_)5FY&@`=[`@@.@56[&,BOSY9N0@`$.QC`B$>5NPQ
M.[\E6>PQ(#H%5KGG8`?C0/+H``2Y@@`(N1H`D+D(`)/L."*_/EGL.`(A'E;C
M@/+P``2YYS`&PDK*8L'6N8(``;D:`$?LV3N_)5FY&@!`[-D@.@56PHK*8L'6
MN0@`3;D:`(;L82*_/EGL80(A'E;L%#N_)5GL%"`Z!5:SP0`!XQ#R^``$N>=@
MT\(:RF+!UKD:`!.SS0`PN8(`V>QY(K\^6;D:`(WL>0(A'E:Y"`"#XY#S```$
MXS#S"``$[`@[OR59[`@@.@56N>=PUL*:RF+!UKF"`-2Y&@"6N1H`'>QD(K\^
M6;D(`!#L9`(A'E;".LIBP=:YYV`'N1H`-^-P\Q``!.Q!.[\E6>Q!(#H%5KF"
M``CLV"*_/EFY&@"0[-@"(1Y6N0@`E+GGT(;L23N_)5FY@@"![$D@.@56N1H`
M.,)ZRF+!UKD(`#2Y&@!V[&$BOSY9[&$"(1Y6[!,[OR59[!,@.@56L\$`,>,0
M\Q@`!+GG8$WLB2*_/EFY@@!)[(D"(1Y6N>>`EKF"`)/"&LIBP=:Y&@`=L\T`
MT[D:`!GLDR*_/EGLDP(A'E;C,/,@``2Y&@!TPCK*8L'6N0@`?;GGD$CLUR"_
M`%6Y"``U[`<[OR59N1H`-NP-`#H%5KD$`%2Y"``0N8(`5^QA(+\`5;D$`'/L
M$3N_)5FY&@!U[!8`.@56N0@`%[D(`&OCD/"@``CGD6``"&+KO0`"``SG^=``
M#FCG\"``.`[LO0`A'E:YZ*"KY[J0``ABXX`@(``(YPO0``YHYP`@$#@.P(H`
M````XX`@(``DU0?S*.`HIW0`!NMO\V``!`?^P.7___'"!P<'!P<'ZV_P,``D
MQ!@``$)MN00`[^/P_V#_<>/@\```).-P$````J>$`%/C`"```)2Y!`""N00`
M8[D$`)*5`"``IX0`2NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8XZ!P```"
MIX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___!`["8`"0!^02F@`)4](`"G
MA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_ZYZ7`[0:F@`>M#``,`"E!`
M8`"Y!``JZV_PT``$!_ZGJ0``I_3_Z:>8``"G]/_#!P<'!P<'!P?KK_!0`"2R
M3P"PN00`[^N[`"``#;)/`+'C\/[(_W'CX/```"2Y!`"B03#PH-('\3"P*,#E
M___Q8^PF`"$`?A@26"#PN*<X0`#`*P``\`#L(P`(@':E#Z``["``$V!VN00`
M*J<Y``+`Y?__\<D0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`!NNO
M\8@`!`?^P.7___$"!P<'!P<'ZV_P,``DLD\`H+D$`._KJ@`@``VR3P"AX_#^
MP/]QX^#P```DT@?Q.*`H["@`"0!\N00`8I4`(`"G=``+U0?Q.*`HIW0`A^MO
M\7``!`?^P.7___'%N00`DNPH__(`?+D$`"G`Y?__\"OL*`!:`'Q!L"`3E2X@
M$Z=T``:5`+`!IX3_\)4N(!.GA`!7IQD``.Q&/+\`5:>$`%JG.0`/N0D`-.<#
M8```-Z<;`!#G(``P`(&GA``,YP%@`$`&IQL`$.<@`#``@:=T__CG`@`'`"%!
M@#`!N80`4+D@`%.YXB`8IR0`->/A7_#_<>Q+/+\`5:<9``"GA``RISD`#[D)
M`#3G0R`3`#>G&P`0YV1`,`"!IX0`*.=!(!-`!J?T__:Y!``IP.7__^Z,N00`
M)L#E___NQZ?T_X:5+K`!IW3_J94`L`*GA/^/I_3_HZ<Y``^G]/^TP.7___!4
MISD`#Z?T_]SG!@`'`"%!@#`!N80`4+D@`%.YXB`8IR3_\>,A7_#_<1KBI^H`
M`KD4`(ZY!``HP.7__^YFX[#PH``DISD``KD$`+*Y!`!(P%```!+0P.7___#G
MN00`*T$P\*C`Y?__[R#L*``-_WY8X/#`IQA``,#K``#P`.SA``^`=KD$`"O`
MY?__\$ZY!``KP.7___")I_3_.;D$`"O`Y?___P:G]/_T!P?K;_`P`"2R3P"@
MP!```$##ZVH`(``-X[`0```$LD\`8;D$`._C\/]8_W'CX/```"3C*V````3$
M2```0+'`4```,MK`,```$H3`Y?__\*CE2/"@``#C*V````3`0```#U/`8```
M$]W`,```$H"Y!`!6P.7__^\$ZV_PV``$!_X'!^M_\#@`)+)/`+"Y!`#OZ[L`
M(``-LD\`L>/P_UC^<>/@\```).,0\*`!<;D$`(/2!Q``L"A!D/"@N00`HKD$
M`#FG20__P"```!)<P.7__^YW["P`$@!^[`+__P#8&!*Y%``@03+PH)4`,`"G
M=``B[`8`'P!^P$```$!.XU!````$N00`.N,EL```!+D$`$C`Y?__[A7CD/"@
M`7'5!Y``L"BG=``IZW_PX`$$!_X8$+D4`'&Y!``IN00`1Z<Y`"_`Y?__[DWL
M*/_8`'S`X```0"/C@.````2Y!`!7XRBP```$N00`2;D$`#K`Y?__[NBG]/_3
MP.7__^]#!P<'!P<'!P?K;_`P`"2R3P!PN00`[^MW`"``#;)/`''C\/]`_W'C
MX/```"1!H#`!E3TP`-('\+AP*+GB<*.G&0``N00`LNPZ/+\`5:>$`'FG*0`/
MN0D`(^<"H```-Z<;`!#G(``P`(&GA``,YP&@`$`&IQL`$.<@`#``@:=T__CG
M`@`'`"%!4"`!N80`0+D@`$*YXB`5IR0`5.-A3_#_<;D$`"OC8/"@`"1!,/"T
MP.7___TMN00`@NPH`$L`?*=I``#L,CR_`%6GA``_IRD`#[D)`"/G0H```#>G
M:P`0YV1`,`"!IX0`#.=&@`!`!J=K`!#G9$`P`(&G=/_XYT8`!P`A00`@`;F$
M`-2Y(`#2N>(@8*<D`!KCD/"@``3C5M_P_W'LE0$(P&7C@/"T`!3$:```/UWK
MB``#``VG]`!8IRD`#Z?T_Y6G*0`/I_3_S\1H```_3>.`8```!.,0@````J>$
M`-^Y!`#HIY@``!C9IYH``4'@X`CC,.````*G=/_XI]H``[D4`!WK,0`#``WC
M,/"H`"3`(```/ZKC$"```!*GA`"6XS#PJ``$N00`*,#E___MB>,@8```)+D$
M`-+L*`!Z`'RY%`!9ZX4``P`-4)#PM*>:``&Y%`"9Z^D``P`-01[0`.5($```
M`.,0L```E+D$`.N5`+``IW0`#:?T`(U!X.`!XQ#@``"4E0#@`*>$``7L%O_W
M/7ZY"0#KN10`/N,@\*``!+D$`-A!(C`"X]!@```(P.7__^Q6XR#0```D["@`
M.0!\XT!@```$XP"P``"0XUA````$09"P`4(`4``8@.P&`!``?*?T`"[C8)``
M`)!!D)`!0F"P`1B&[&@`)`!\0H#PH+D$`+65/?"@05!0`:=T_^V2/;``I^D`
M`.,>H```D$(>L`&GZP`![!;_^0!\U0?PN'`HIW0`.NMO\/``!`?^N00`M:?T
M_^?C(/"H``3`0```/POE3$````'`Y?__[`&Y!`#2["C_Y0!\XU#PJ``$N10`
M";D$`#CK@``#``VY!`!(P.7__^Z=X]!@```DI_3_7J<Y``"G]/^#Y4CPJ``0
MIY@``*?T_S;`Y?__[:JG.0``XR.@``"00B.``*<[``'L)O_Y`'RG]/^T!P<'
M!P<'!P<'![)/`"#`$```/E[K4@`@``WC,!````2R3P!1Q$@``#Y7XR-0```$
MP%```#!]P#```!`GP/3__^Y+!P<'!P<'!P?K;_`P`"2R3P"0N00`[^N9`"``
M#;)/`)'C\/](_7'CX/```"3C$/"P`G'CL/"O`7'2!Q``D"C`Y?__[1G`````
M$";C`/"@`"2Y!`!BITD0`:<Y``*Y!``KP%```!`208#PKL#E___N`[D$`"NY
M!``XITD0`,#E___L&NPD`#$`?NQR``$`V+D$`&*Y%`!WN00`)\#E___K6[D$
M`*+L*``2`'RY%`"VN00`5[D$`#BY!`!+P.7__^O+02N@`)(`(`#C,/"P`G'5
M!S``D"BG=``,N00`*NMO\.@"!`?^IZD``*?T__#`Y?__[0('!P<'!P?`]/__
M_X@'!P<'!P<'!P<'ZV_P,``DLD\`T+D$`._KW0`@``VR3P#1X_#^L/YQX^#P
M```DXQ#Q2`%QN00`HM('$`#0*+D$`)/`(```#ZM!,/"TP.7___L7ISD`+[D$
M`+*Y!``JP.7__^S:["@`&0!\P"````^<N00`.L#E___]@[D$`"KC</%(`7'5
M!W``T"BG=`&8ZV_Q@`$$!_ZY!``IP.7__^O<P#````^(P.7__^LFN00`8NPH
M_]T`?.R*/+\`54&0\4A!</"XE0!@`*>$`+;LN``/`'RG"```N00`-KD$`"NR
M70`RIQ3__J>$`):G20``[`8\OP!5IX0!)J=9``^Y"0!0YP5@```WITL`$.<@
M`#``@:>$``SG!&``0`:G2P`0YR``,`"!IW3_^.?B``<`(4$P4`&YA``>N2``
M%;GB($.G)`$!X^0?\/]QXUYO__]Q[&4`?Z!EN>E@):<A``&GA``.E2]0`*=T
M`/*2`%``XU!?__]Q[&4`&8!DZT(``0`,E2]0`*=T`..2`%``ZR]?__]5IW0`
MW.L`7___4N-07_[_<:='_^^G:0``[$4\OP!5IX0!`J?I``^Y"0#DYQY0```W
MIVL`$.<Q$#``@:>$``SG%E``0`:G:P`0YS$0,`"!IW3_^.<#``<`(4$PX`&Y
MA``0N2``'KGB(&.G)`#=X^8?\/]QN00`9:?T`".5`+`!IW0`&L`P```.SZ<I
M``#`Y?__ZFNY!`!B["C_(@!\E0!@`*=T_T[LN``'`'R5+K``IX3_YJ?I``'`
M8```#JBG60``[(@`=`!\IRD`#[D)`"CG4J```#>G6P`0YW50,`"!IX0`#.=5
MH`!`!J=;`!#G=5`P`(&G=/_XYT<`!P`A00`@`;F$`!2Y(``2N>(@4*<D`$[C
M-1_P_W&G60__0>/@`>SE_MX@9>.@\*@`),!````.?.-`\*``)*<Y``*Y!``I
MP%````[IITD0`,#E___L3;D$`#>Y!``IP.7__^J&[";_DP!^6&#PT*4O@`#`
M:P``\`#L8O^)8':Y!``IISD``<#E___L(NPF_W\`?KD$`#G`(```#D+`Y?__
M_"NY!``IP.7__^J2I_3^I:<I``^G]/^;IUD`#Z?T_NBG60``[`8\OP!5IX0`
M+*?I``^Y"0#@YTY@```WIUL`$.=D0#``@:>$``SG16``0`:G6P`0YV1`,`"!
MIW3_^.<6``<`(4$@X`&YA``QN2``/KGB(%*G)``'X^4_\/]QI_3_4Z?I``^G
M]/_BI^D`#Z?T_PS`Y?__ZQP'!P<'!P<'!P<'Z[_P6``DN00`[^/P_V#_<>/@
M\```)+D$`+*G.0`OP.7__^NE01`@`;D"`"*Y!``KN>)P(>N_\/@`!,#T___J
M)^N?\$@`)+)/`*"Y!`#OZZH`(``-LD\`H>/P_UC^<>/@\```).,0\*`!<=('
M$`"@*.PH`)D`?+D$`#*5`"``IX0`DJ=9``#L0CR_`%6GA`"'IRD`#[D)`"3G
M`C```#>G6P`0YR``,`"!IX0`#.<%,`!`!J=;`!#G(``P`(&G=/_XYP(`!P`A
M0;`@`;F$`)"Y(`"2N>(@6Z<D`&+CE9_P_W&GZ1``[$D``0#9[$X`;2!E0;#P
MH+D$`"O`Y?__Z[CC&;___W'L&P`KP&6YZ;`QIQ$``:>$``Z5+Q``IW0`()(`
M$`#C$!___W'L&P`9@&3K4P`!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?
M__]2XQ`?_O]QIU?_[[D$`"NG.0`OP.7__^L#["@`'0!\["L`!<!ED@`@`+D$
M`"O`Y?__Z8;C0/"@`7'5!T``H"BG=``?ZY_P\`$$!_ZG*0`/I_3_A^,@\*`!
M<=4'(`"@**=T``_`(```#0WKG_#P`03`]/__Z66G*0``I_3_W<#E___J+@<'
M!P<'!P<'!P<'!P<'ZZ_P4``DLD\`H+D$`._KJ@`@``VR3P"AX_#_4/]QX^#P
M```D0;#PI-('\*B@*+D$`#O`(```#.S`Y?__^$SL*``N`'S$2```.K;C(/"D
M`!3K$@`#``WC$$````CC4!`(``3C4!```"3L6/_C`'SC`!`0``1!$!`(XP`0
M```D[`;_^`!\N00`.\`@```,P<#E___X(>PF_]@`?+D$`#O`(```#+O`Y?__
M^!;L*``N`'S$6```.H#C$/"D`!3KX0`#``WCX%````CC`.`(``3C`.```"3L
M"/_C`'SC,.`0``1!X.`(XS#@```D[#;_^`!\N00`.\`@```,D,#E___WZ^PF
M_]@`?+D$`#O`(```#(G`Y?__]^#L*``N`'S$6```.DKCX/"D`!3K3@`#``WC
M0%````CC,$`(``3C,$```"3L./_C`'SC($`0``1!0$`(XR!````D[";_^`!\
MN00`.\`@```,7L#E___WM>PF_]@`?+D$`#O`(```#%C`Y?__]ZKL*``N`'S$
M.```.A3C(/"D`!3K$@`#``WC$#````CC0!`(``3C0!```"3L2/_C`'SC`!`0
M``1!$!`(XP`0```D[`;_^`!\N00`.\`@```,+<#E___W?^PF_]@`?+D$`#O`
M(```#";`Y?__]W3L*``N`'S$2```.=[C$/"D`!3K40`#``WC4$````CC`%`(
M``3C`%```"3L"/_C`'SCX%`0``1!4%`(X^!0```D[.;_^`!\N00`.\`@```+
M^\#E___W2>PF_]@`?+D$`#O`(```"_C`Y?__]S[L*``N`'S$2```.:CC4/"D
M`!3K-0`#``WC,$````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``1!,#`(XR`P
M```D[";_^`!\N00`.\`@```+S<#E___W$^PF_]@`?+D$`#O`(```"YK`Y?__
M]PCL*``N`'S$Z```.7+C(/"D`!3K$@`#``WC$.````CC,!`(``3C,!```"3L
M./_C`'SC`!`0``1!$!`(XP`0```D[`;_^`!\N00`.\`@```+;\#E___VW>PF
M_]@`?+D$`#O`(```"Y+`Y?__]M+L*``N`'S$.```.3SC$/"D`!3K00`#``WC
M0#````CC`$`(``3C`$```"3L"/_C`'SC4$`0``1!0$`(XU!````D[%;_^`!\
MN00`.\`@```+9\#E___VI^PF_]@`?+D$`#O`(```"V'`Y?__]ISL*``N`'S$
M.```.0;C0/"D`!3KY``#``WCX#````CC4.`(``3C4.```"3L6/_C`'SC(.`0
M``1!X.`(XR#@```D[";_^`!\N00`.\`@```+-L#E___V<>PF_]@`?+D$`#O`
M(```"S#`Y?__]F;L*``N`'S$6```.-#CX/"D`!3K'@`#``WC$%````CC(!`(
M``3C(!```"3L*/_C`'SC`!`0``1!$!`(XP`0```D[`;_^`!\N00`.\`@```+
M!<#E___V.^PF_]@`?+D$`#O`(```"L?`Y?__]C#L*``N`'S$*```.)KC$/"D
M`!3K,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``1!,#`(XT`P
M```D[$;_^`!\N00`.\`@```*G,#E___V!>PF_]@`?+D$`#O`(```"LG`Y?__
M]?JY!``R["@`"0!\P"````JTP.7___AON00`.\`@```*O\#E___UY[D$`#+L
M*``)`'S`(```"KW`Y?__^%RY!``[P"````J[P.7___74N00`,NPH`!H`?,`@
M```*6\#E___X2=4'\*B@**=T`"/`,```"K;`(```"FWKK_$```3`]/__^#BY
M!``[P"````J?P.7___6PN00`,NPH_^4`?,`@```*9<#E___X):?T_]S`Y?__
MYUP'!P<'!P<'!P<'Z[_P6``DLD\`L+D$`._KNP`@``VR3P"QX_#_4/]QX^#P
M```D03#PI,`@```*0=('\*BP*,#E___U?NPH`"``?$,0(``8(<`G````,+F$
M``*Y`P`PIQ$`_^M#`#\`#.Q(````0M4'\*BP*+D4`"2G=``*Z[_Q"``$!_ZG
M2```I_3_\\#E___G$P<'!P<'!P<'8`#P@&`@\(A@0/"08&#PF.L_\!@`),08
M```WY;)/``"Y!`#OX_#_./]QX^#P```DN00`0NLP`"``#>,@$```!+)/`#%!
MX/#(T@?PP#`HX^#PN``DY4CPH``!Y4CPJ```05#PH$%@\6CC8/"P`"2G.0`"
MP.7__^:CIRD`_\#E___F7@<'!P<'!P<'!P<'!P<'ZW_P.``DLD\`D+D$`._K
MF0`@``VR3P"1X_#_4.]QX^#P```DXQ#PJ!!QISD``-('$`"0*+D$`'*G20`"
MP.7__^3VP#'__P``[*+__P#9[`HP@`!5N00`(*<+__^Y@0`#IPL``;D"`*JY
MXJ`"N0D`H.RD`)(`?$&P\*#`@```-WNY!``ZN00`)Z=)``#`Y?__Y,[L*`";
M_WRY!``[N00`)\!!``$`",#E___FT>PH`(C_?KD4`$+L3`!F!WWC%+_X_W'L
M&P!@0&7C4(````3LX3Z_`%7C4!```""GA`!KXQ`?__]Q[!L`3T!E[.@`)`!\
M[.@`%@%\[.@`"P)\XU`0```@IX0`5^,0'___<=4'@``0`*>$`$_C$!___W'5
M!X``$`"GA`!'XQ`?__]Q[!L`*T!EXP"````$XP`0```@IX0`.>,@'___<;D$
M`!+C`"```""GA``OXQ`O__]QXP`0```@IX0`)^,0+_[_<>,`+_[_(*>$`!_C
M$"_]_W'L&__;H&7"I``!``#`,?__``#LH_]Y8&2G*?__XW#PJ!!QU0=P`)`H
MIW0`&.M_\.@0!`?^N>FP(;D(`"JG]/_PP"````DGP.7___[7P"````D:P.7_
M__[1P.7__^7:!P<'!P<'Z^_P<``DN00`[^/P_V#_<>/@\```),#E___CN<#E
M___CENPH``8`?.,@(```!.OO\1``!`?^!P<'!P<'!P<'!^MO\#``)+)/`*"Y
M!`#OZZH`(``-LD\`H>/P_T#_<>/@\```)+D$`&)!,/"TT@?PN*`HP"````CB
MP.7___/<["@`"0!\N00`LI4`(`"G=``2U0?PN*`HIW0`6KD$`#;`(```",SK
M;_#P``3`]/__]D.G&0``[#8\OP!5IX0`1*<I``^Y"0`CYP)@```WIQL`$.<@
M`#``@:>$``SG`6``0`:G&P`0YR``,`"!IW3_^.<"``<`(4%0(`&YA`!`N2``
M0KGB(!6G)``?XY%/\/]QI^D``.P;/+\`5:>$`!RG*0`/N0D`(>="L```-Z?K
M`!#G9$`P`(&GA``2YTZP`$`&I_3_]J<I``^G]/_*P.7__^4OIRD`#Z?T__+G
M-@`'`"%!`"`!N80`0[D@`$*YXB#@IR3_\>->3_#_<4&94`*Y!``IP.7__^-$
MX[#PJ``DP+````?MX[#PH``DN00`2<!0```(7;D$`)*G.0`"P.7__^6_U0?P
MN*`HIW3_RKD$`#G`(```"#SK;_#P``3`]/__];/K;_`P`"2R3P`0N00`[^/P
M_BC_<>/@\```)*?K__A@@.``ZS$`(``-LD\`,<!````URN,P\,``)-('\<@P
M*$&`\,RY!`#2N00`.-)'\/!`$-(/\-A`6-('\.A`:,`@```'D<#E___R_^PH
M``D`?+D$`+*5`"``IW0!?<#E___BG\#E___B?.PH`#@`?..@(````J>$`#*G
MZ0``[`H\OP!5IX0`)Z<I``^Y"0`@YP*@```WI^L`$.<@`#``@:>$``SG#J``
M0`:GZP`0YR``,`"!IW3_^.=2``<`(4%@(`&YA`!5N2``4KGB(.:GQ`$GIRD`
M#Z?T_^=!</#8XR!P```"IX0`%;D$`#C`Y?__\JSL*``'`'R5`"``IW0`VJ=[
M``CC('````*G=/_OIRD`#:=Y``W`Y?__XH.GN0`-N00`DK/!`(+`H```!YFG
M&`!3N00`2[D$`"FY%@!AISD``L!0```'D,#E___D^KDA`'NY!``[N>*@-[GI
ML!.G&P`"N2$`$[GB4!.Y"0"S0:"@`>.['_[_<4&0D`+C$*```)25`*``IW3_
MUD&0\1#`(```!SFG]``)IYL`".,@G_C_`J>$`""Y!``XP.7___)-N00`HNPH
M__(`?)4`(`"GA/_MP.7___*Q["C_Z`!^N00`*L#E___C);D$`&+L)@`=`'Q!
M</#PXV!P```"IX0`%94`8`"GA`#@N00`)L#E___RE.PF`,(`?J=[``CC8'``
M``*G=/_OI^D``.Q&/+\`5:>$`,:G*0`/N0D`).<28```-Z?K`!#G,1`P`(&G
MA``,YQY@`$`&I^L`$.<Q$#``@:=T__CG`P`'`"%!,"`!N80`4+D@`%*YXB#C
MIR0`H;/-`)CCOE_P_W&G&0``[*D\OP!5IX0#$*?I``^Y"0#JYUZ0```WIQL`
M$.=U4#``@:>$`):SS0!(YU%``$`&I_3_],#E___BMJ=[``BY!`"B["C_$`!\
MI^D``.Q"/+\`5:>$`%BG*0`/N0D`).="H```-Z?K`!#G9$`P`(&GA``,YTZ@
M`$`&I^L`$.=D0#``@:=T__CG!@`'`"%!8"`!N80`4+D@`%*YXB#FIR0`,^-^
M7_#_<>NW``$`#:>[``&Y!``KP.7__^%VXQ"@``"4N00`DI4`H`"GA``\N00`
M>[/!`(*G]/[QP.7___V`XT#PP``$U0?QR$`HIW0`+VB`\="Y!``KZV_R"``$
MP/3__^)2IRD`#Z?T_[:Y!``FIWL`",#E___B1[D$`&+L*/\G`'RGZ0``[$8\
MOP!5IW3_/J<I``^G]/](IVD``*?T_R^SP0""I_3^Y<#E___B_.<G``<`(4$`
MX`&YA`!2N2``7KGB(!"G)`)AXS%?\/]Q&CNG.@0$N10`<[D$`"?`Y?__X1)@
M@/"PP!````6]XQ#PH``DP+````8RX[#PJ``DN00`DJ<Y``*Y!`!'P%````8A
MP.7__^.(N00`*:<Y`<#`Y?__XG'L)@`+_W[`Y?__XCM88"``[&8!7!%^0:#Q
M.+/!`(JY!``IN00`.L#E___BVQBR["8`#0!^6.#Q4*=(0`#`ZP``\`#LY``H
M@';$B```,W[C4-````3C((````2Y!`!IP$````8+ISD``L#E___BJJ>I``#C
M,/#```35!_'(,"BG=/^#N00`*FB`\=#K;_((``0'_EA@\53`Y?__X&/L8O_6
M8'984/%0IR@!P,!;```!_^Q2_\Q@=KD$`"?`Y?__X)&Y!``XN00`HL`@```&
M`,#E___PF[D$`#+L*`#J`'SC(-````3`Y?__]5BY!`!B["@`WP!\IQD``.P&
M/+\`5:>$`.&GZ0`/N0D`X.<.8``(-Z<;`!#G(``P#H&GA``,YP%@`$@&IQL`
M$.<@`#`.@:=T__CG,@`'!"%!4.`!N80`0[D@`$ZYXB`5IR0`O.,A3_#_<>PL
M`"`#?KD4`!+`X```!;GC,6_\_W&G"```LET`XZ<4__ZG=``/["@!*@1^IRK_
M^[D4`$)!5&``E2]0`*>$`1^Y!``XP"````3TP.7___`T["@`K0!\XX`@``"4
M[(@`IP!^[(@`I#!^P#````4:P"````3?P.7___*?P.7__^&8XR#PJ``DP```
M``7CXP#PL``DP#````2LXS#PH``DN00`:;D$`$>Y!``JP%````5]ISD``L#E
M___B>Z?T`#+`Y?__X3980"``ITX`$:=T`#/`Y?__X6WC(/"H`"2GN@`!P!``
M``6VXQ#PN``DN10`6^-0\+``),"````$>N.`\*``)+D$`&FY!`!'N00`*L!0
M```%4J<Y``+`Y?__XDFY!``JISD!P,#E___A,NPH_\G_?KD$`"G`Y?__X?JY
M!``ZP"````1(P.7___(VN00`*L#E___[N:?T_N7C8-````2G&0``[`8\OP!5
MIW3_(Z?I``^G]/\MQ"@``#(^N10`9N-@\*``).-0T```!.,@(```!+D$`&G`
M0```!*BG.0`"P.7__^%EI_3^N[D$`":G.0``P.7__^',N00`TNPH_U8`?L#E
M___Z<+D$`&+L)/].`'RG20``XS!O]O]QN00`+<#E___?=;D$`"U!,/#2ITD`
M!L#E___A?.PF`)`&?,#@```D%]4%X`#PTJ=T_R_C,&_._W&G20``N00`+<#E
M___?5[/-`#BY!``MITD`*,#E___A7NPF`'(H?&"`\*B2`/%@P-````4%X]#P
ML``DP.````/.X^#PH``DN00`1[D$`&FY!``JP%````27ISD``L#E___AG:?T
M_U[CT-`(``*GA/[@IRD``.P-/+\`5:>$`#VG&0`/N0D`$.=!T``(-Z<K`!#G
M9$`P#H&GA``,YT+0`$@&IRL`$.=D0#`.@:=T__CGY@`'!"%!,!`!N80`3KD@
M`$&YXB`CIR0`&.-23_#_<>Q<_J\#?>,5W_S_<<`@```$2J<(``"R70`AIQ3_
M_KGB@&VG]/Z>IQD`#Z?T_]&GZ0`/I_3\_L`@```$.,#E___Y>@<'!P<'!P<'
M!P<'!P<'ZW_P.``DLD\`L,"@```Q0^N[`"``#>,0H```!+)/`+&Y!`#OX_#_
M4/]QX^#P```DT@?PJ+`HXY&P```$08#PI,`@```#3](`D+&0L+D$`#C`Y?__
M[ICL*``'`'R5,2``IX0`TL#E___V)N,@H```!..2L```!+D$`"FG60`#ITD`
M`<`P```$",#E___>R+D$`)+L*``?`'SC,"`0``3C<*````3C,#````3C)[``
M``3`0````_+`Y?__WL'C0)`0``3C,$````210#`-IW0`K^-PH```!*=9``/C
M)[````2G20`!P#````/;P.7__]Z7N00`DNPH`!P`?+D$`#C`(````M7`Y?__
M[C[C4)`0``2Y!`!"XS!0```$["@`>P!\XR>P```$P.7__]Z)XZ"@```$ITD`
M`>-ZL```!,`P```#L+D$`"?`Y?__W=G`0````[.Y!``RN00`)\#E___>;^,:
ML```!+D$`#B2`!"QP"````*8P.7__^X&Q"L``##[N00`@NPH`"P`?+D$`"BG
M.0'`P.7__]]C[`(``0#8[`P`%@%_["@`$Q%^Q+@``##?N00`4N,PL```!+D$
M`$C`(````X[`Y?__W^K5!_"HL"BG=``UZW_PZ``$!_[$*```,,;`Y?__^I_$
M*P``,,2Y!`""[";_S`!\P"````-@P.7__]_-E0`@`:>$_S>G]/\LQ.@``#"L
MN00`(^,PX```!,#E___OL*?T_X/C)[````3`Y?__WU2G]/]-P.7__]]?ZY_P
M2``DLD\`H+D$`._KJ@`@``VR3P"AX_#_4/]QX^#P```DN00`LD$P\*32!_"H
MH"C`(````D3`Y?__[83L*``3`'SC$"```)3L&``-`'[L&``*,'[LN``'`'R5
M`+``IW0`"]4'\*B@**=T`#7KG_#X``0'_KD$`"O`Y?__]"NG.0`ON00`DL#E
M___?N+D"`")!`"`!N00`*;GB<"#`Y?__WCVG20`$P#````)CP.7__]W%[";_
MV`!^U0?PJ*`HIW0`"KD$`"OKG_#X``3`]/__[?G`Y?__WO('!P<'!P?KW_!H
M`"3`T```(<FY!`#OX_#_8/]QX^#P```DIRD`@,#E___=#.<`T"`P!N<@T!`P
M!N=`T``P!N<`(``P#N<@(!`P#N=`("`P#N5((#```.5,('@``.O?\0@`!`?^
M!P?K;_`P`"2Y!`#OX_#_6/]QX^#P```DI^O_^&"`X`"Y!`"2ZQ0``P`-XU`@
M*``$ZP0`'0`,N0@`%>PA(+\`5;DQ`%&Y!`"$XP"0,`"(N00`T^<"````8N-@
MD'@`$N<`D"@P#J=T`$=!<)`X[(P`,C]^ZV@`!@#>N00`K>SF(+D&6:=J__^G
MZ__`N18`5NN^``8`#+/!`(6GNP`!TC]P`*``N00`*4&@H$#`Y?__X7RGM__V
ML\T`&*>*_\")8``&ZR$`!@`-&X9!TM!`N10`B+D$`#VY!``GN00`2,#E___?
M;U"`D'AH@/"@ZV_PV``$!_ZGN`!`&[89M$%PD#BY\C"TN00`)[D8`":Y%`"K
MN00`2L#E___?5!@[6C"0>%`PD'CL-O_B0'ZY^;!(N00`*;D(`-JY%`"$P.7_
M_^$UI_3_E^N/\$``),#0```A$;D$`._C\/]@_W'CX/```"3CD#`H``2Y!`"S
MXX`P,``$[!DZOSU9N10`,4%#L#B2@$``IQH``;D$`**Y%``A03*P..P<`&0X
M?J=(`$"Y^1`D[$$`"X!VYP````!$IRK__^<",```/[D$`"O`Y?__X/77-[`X
ML#AH(-``ZQ@`&``,ZS@`$``,ZP@`"``,ZUD`&``,Z^D`"``,YR$````BYR,`
M`0`BYR```@`BYR@``P`BZXD`$``,YR4`!``BYR@`!0`BYRX`!@`BYRD`!P`B
M8""P<+D$`"O`Y?__X+_2`Z``L`2Y!``KT@.@!+`,T@.@"+`4T@.@#+`<T@.@
M$+`DZX_PX``$P/3__]X4IP@`.+GY$%#L`?^R@':G6O__N18`Y<;@````!:?T
M_ZC7`#``,``'!P<'Q%@``"YLP/3__]NY!P<'!^MO\#``).,0\'@`!*?[_V#C
M$/```"3`P```+3GC0/$0``3K;_#0``0']``````````"``$E<R\E<P!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M`"]P<F]C+W-E;&8O97AE```O<')O8R\E:2\E<P!E>&4`+@!005)?5$5-4```
M4$%27U!23T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0`
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'
M3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.```Q`&QS965K(&9A:6QE9```<F5A9"!F86EL960`3$1?
M3$E"4D%265]0051(`%-94U1%30``)3`R>```)7,E<R5S)7,``'!A<BT``"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H``%!!5$@``'!A<FP``"YP87(``'-H;W)T(')E860``"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,``!@`<&5R
M;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-C,`56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"UE
M```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I
M>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH
M(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")0
M2UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]
M($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M
M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT
M:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@
M)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L
M96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@
M)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S
M("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE
M;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO
M9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V
M+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N
M86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*
M7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F
M(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").
M;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q
M6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L
M("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@
M)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O
M9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T
M96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B
M1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL
M;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T[
M"G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF
M:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)
M0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P
M87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?
M34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?
M1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#
M3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?
M;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*
M?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B
M)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C
M=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D[
M"GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T
M7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H
M95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII
M9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A
M9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O
M9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*
M?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I
M"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B
M?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!54T52``!54T523D%-10``
M5$5-4$1)4@!435``+W1M<```````````P]+A\````````````````)BZW/X`
M````$#)4=@````!G12,!`````._-JXD``````````'!E<FQX<VDN8P``0T%#
M2$4```````````$;`SL```#L````'/__?%@```8,__]^Z````0C__X`8```!
M./__EG@```%X__^76````<C__Y?X```!^/__F?@```(T__^:>````G#__YMX
M```"K/__GL@```+L__^?"````P#__Y_X```#//__H`@```-0__^CR````XS_
M_Z0(```#N/__I:@```/\__^K2```!##__ZO8```$8/__K&@```2,__^N2```
M!,C__ZZ(```$Z/__L!@```4T__^X^```!8S__[LX```%R/__O!@```9,__^\
M>```!G#__[VX```&L/__OO@```;H`````````!0``````7I2``%X#@$;#`^@
M`0<.`````!0````<__]]V````$(``````````````!0``````7I2``%X#@$;
M#`^@`0```````#P````<__]^V```%EH`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M3@[0!P,6/@K/SLW,R\K)R,?&#J`!0@L```````!,````7/__E/@```#8`$R&
M#H<-B`R)"XH*BPF,"(T'C@:/!4H.P`("D@K/SLW,R\K)R,?&#J`!0@M<"L_.
MS<S+RLG(Q\8.H`%""P```````"P```"L__^5B````)H`1HH*BPF,"(T'C@:/
M!5@.V`,"=`K/SLW,R\H.H`%""P```#@```#<__^5^````?X`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%6`[@`VX*S\[-S,O*R<C'Q@Z@`4(+`````#@```$8__^7
MO````'X`1H8.APV(#(D+B@J+"8P(C0>.!H\%9`[(`@)2S\[-S,O*R<C'Q@Z@
M`0```````#@```%4__^8`````/@`1H<-B`R)"XH*BPF,"(T'C@:/!5@.R"("
MC`K/SLW,R\K)R,<.H`%""P```````#P```&0__^8Q````T8`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%6`[@`@,"G`K/SLW,R\K)R,?&#J`!0@L````````0```!
MT/__F]0````X`````````#@```'D__^<`````.H`1H8.APV(#(D+B@J+"8P(
MC0>.!H\%6`[80@*\"L_.S<S+RLG(Q\8.H`%""P```!````(@__^<M`````8`
M````````.````C3__YRP```#M@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP58#O`C
M`FP*S\[-S,O*R<C'Q@Z@`4(+````*````G#__Z`T````0`!&BPF,"(T'C@:/
M!4H.P`)JS\[-S,L.H`$```````!````"G/__H$@```&2`$:)"XH*BPF,"(T'
MC@:/!5@.R"(#`3H*S\[-S,O*R0Z@`4(+9`K/SLW,R\K)#J`!1@L``````#``
M``+@__^AI```!98`1HH*BPF,"(T'C@:/!5@.T`(#!4(*S\[-S,O*#J`!1@L`
M```````L```#%/__IQ````"(`$:+"8P(C0>.!H\%6`[0`@):"L_.S<S+#J`!
M0@L````````H```#1/__IW````""`&"&#H<-B`R)"XH*BPF,"(T'C@:/!4H.
MZ`(``````#@```-P__^GU````=H`1H<-B`R)"XH*BPF,"(T'C@:/!5@.T(($
M`P&0"L_.S<S+RLG(QPZ@`4(+`````!P```.L__^I>````#8`1HX&CP5*#L`"
M9,_.#J`!````2````\S__ZF8```!D`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP58
M#N`"`DP*S\[-S,O*R<C'Q@Z@`48+`P$:S\[-S,O*R<C'Q@Z@`0```%0```08
M__^JW```"-(`2H8.APV(#(D+B@J+"8P(C0>.!H\%2@[X!$Z8%0,#<@K/SLW,
MR\K)R,?&V`Z@`48+`P%2"L_.S<S+RLG(Q\;8#J`!0@L````````X```$</__
MLV0```)``$:'#8@,B0N*"HL)C`B-!XX&CP5D#M`"`P&P"L_.S<S+RLG(QPZ@
M`4(+``````!````$K/__M6@```#:`$:)"XH*BPF,"(T'C@:/!5@.T`("5@K/
MSLW,R\K)#J`!0@L"6`K/SLW,R\K)#J`!1@L``````#P```3P__]V1````I``
M1H8.APV(#(D+B@J+"8P(C0>.!H\%6`[H`@,!O@K/SLW,R\K)R,?&#J`!0@L`
M```````@```%,/__M<0```!>`$:-!XX&CP50#L`"`D;/SLT.H`$````\```%
M5/__M@````%``$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.R`).F!4"T`K/SLW,
MR\K)R,?&V`Z@`4(+````-```!93__[<````!/`!&B`R)"XH*BPF,"(T'C@:/
M!5`.P`("^@K/SLW,R\K)R`Z@`48+```````0```%S/__N`@````,````````
M```````$````$`````%'3E4```````````,````"``````````0```!@ROX:
M?D9$3P![(G1Y<&4B.B)D96(B+")O<R(Z(G5B=6YT=2(L(FYA;64B.B)G;&EB
M8R(L(G9E<G-I;VXB.B(R+C0Q+3%U8G5N='4Q(BPB87)C:&ET96-T=7)E(CHB
M<S,Y,'@B?0`````````$````;,K^&GY&1$\`>R)T>7!E(CHB9&5B(BPB;W,B
M.B)U8G5N='4B+")N86UE(CHB;&EB<&%R+7!A8VME<BUP97)L(BPB=F5R<VEO
M;B(Z(C$N,#8S+3%B=6EL9#(B+")A<F-H:71E8W1U<F4B.B)S,SDP>")]````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```D0````````"/P``````````$````````"V@`````````!`````````NH`
M````````#````````!EH``````````T```````!C0``````````9````````
MN[@`````````&P`````````(`````````!H```````"[P``````````<````
M``````@`````;__^]0````````*H``````````4````````,0``````````&
M`````````X@`````````"@````````1F``````````L`````````&```````
M```5`````````````````````P```````+W(``````````(````````%$```
M```````4``````````<`````````%P```````!18``````````<````````1
MT``````````(`````````H@`````````"0`````````8`````````!X`````
M````"`````!O___[``````@```$`````;____@```````!%@`````&____\`
M`````````0````!O___P````````$*8`````;___^0`````````0````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"[R```````````
M```````````````````9U@```````!GV````````&A8````````:-@``````
M`!I6````````&G8````````:E@```````!JV````````&M8````````:]@``
M`````!L6````````&S8````````;5@```````!MV````````&Y8````````;
MM@```````!O6````````&_8````````<%@```````!PV````````'%8`````
M```<=@```````!R6````````'+8````````<U@```````!SV````````'18`
M```````=-@```````!U6````````'78````````=E@```````!VV````````
M'=8````````=]@```````!X6````````'C8````````>5@```````!YV````
M````'I8````````>M@```````![6````````'O8````````?%@```````!\V
M````````'U8````````?=@```````!^6````````'[8````````?U@``````
M`!_V````````(!8````````@-@```````"!6````````('8`````````````
M``````````````````````````!=,```````````````````````````````
M````````````````````````````````````````````````````P(``````
M`````````````""0``````````````````#`"`I005(N<&T*````````````
M``````"CX````````&/,``````````````````!D;````````&1P````````
MH]0```````!CT@```````*/<``````````````````"CQ````````*/*````
M``````````````!F5$=#0SH@*%5B=6YT=2`Q-"XR+C`M,3=U8G5N='4S*2`Q
M-"XR+C```"YS:'-T<G1A8@`N;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FYO=&4N04))+71A
M9P`N;F]T92YP86-K86=E`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M```````````+````!P`````````"`````````G`````````"<``````````D
M````````````````````!```````````````'@````$``````````@``````
M``*4`````````I0`````````#P````````````````````$`````````````
M`"9O___V``````````(````````"J`````````*H`````````-P````$````
M```````````(```````````````P````"P`````````"`````````X@`````
M```#B`````````BX````!0````(`````````"``````````8````.`````,`
M`````````@````````Q`````````#$`````````$9@``````````````````
M``$``````````````$!O____``````````(````````0I@```````!"F````
M`````+H````$```````````````"``````````(```!-;____@`````````"
M````````$6`````````18`````````!P````!0````$`````````"```````
M````````7`````0``````````@```````!'0````````$=`````````"B```
M``0```````````````@`````````&````&8````$`````````$(````````4
M6````````!18````````!1`````$````%@`````````(`````````!@```!P
M`````0`````````&````````&6@````````9:``````````^````````````
M````````!```````````````:P````$`````````!@```````!FH````````
M&:@````````&X`````````````````````0`````````(````'8````!````
M``````8````````@D````````""0````````0K`````````````````````0
M``````````````!\`````0`````````&````````8T````````!C0```````
M```J````````````````````!```````````````@@````$``````````@``
M`````&-P````````8W````````!`R`````````````````````@`````````
M`````(H````!``````````(```````"D.````````*0X`````````.P`````
M```````````````$``````````````"8`````0`````````"````````I2@`
M``````"E*`````````80````````````````````"```````````````H@``
M``<``````````@```````*LX````````JS@`````````(```````````````
M``````0``````````````+`````'``````````(```````"K6````````*M8
M`````````.P````````````````````$``````````````"^````#@``````
M```#````````N[@```````"[N``````````(````````````````````"```
M```````(````R@````\``````````P```````+O`````````N\``````````
M"`````````````````````@`````````"````-8````&``````````,`````
M``"[R````````+O(`````````@`````%```````````````(`````````!``
M``#?`````0`````````#````````O<@```````"]R`````````(X````````
M````````````"``````````(````Y`````$``````````P```````,``````
M````P```````````B`````````````````````@``````````````.H````(
M``````````,```````#`B````````,"(`````````"@`````````````````
M```(``````````````#O`````0`````````P``````````````````#`B```
M```````F`````````````````````0`````````!`````0````,`````````
M````````````````````P*X`````````^`````````````````````$`````
$````````
